@@ -64,7 +64,7 @@ char *fake = N_("Test if Mp is a Mersenne prime using the Lucas-Lehmer test");
 char *fake = N_("Return all maximal prime power factors of a number");
 char *fake = N_("Vector with the known Mersenne prime exponents");
 char *fake = N_("Return the Moebius mu function evaluated in n");
-char *fake = N_("Returns the padic valuation (number of trailing zeros in base p).");
+char *fake = N_("Returns the p-adic valuation (number of trailing zeros in base p).");
 char *fake = N_("Compute a^b mod m");
 char *fake = N_("Return all prime factors of a number");
 char *fake = N_("Pseudoprime test, true iff b^(n-1) == 1 (mod n)");
@@ -74,7 +74,7 @@ char *fake = N_("Find square root of n mod p (a prime). Null is returned if not
 char *fake = N_("Apply a function over all entries of a matrix and return a matrix of the results");
 char *fake = N_("Apply a function over all entries of 2 matrices (or 1 value and 1 matrix) and return a matrix of the results");
 char *fake = N_("Remove column(s) and row(s) from a matrix");
-char *fake = N_("Calculate the kth compund matrix of A");
+char *fake = N_("Calculate the kth compound matrix of A");
 char *fake = N_("Delete a column of a matrix");
 char *fake = N_("Delete a row of a matrix");
 char *fake = N_("Get the dot product of two vectors (no conjugates)");
@@ -93,7 +93,7 @@ char *fake = N_("Removes any all-zero rows of M");
 char *fake = N_("Return column(s) and row(s) from a matrix");
 char *fake = N_("Swap two rows in a matrix");
 char *fake = N_("Zero out entries below the diagonal");
-char *fake = N_("Get the auxilliary unit matrix of size n");
+char *fake = N_("Get the auxiliary unit matrix of size n");
 char *fake = N_("Evaluate (v,w) with respect to the bilinear form given by the matrix A");
 char *fake = N_("Return a function that evaluates two vectors with respect to the bilinear form given by A");
 char *fake = N_("Get the characteristic polynomial as a vector");
@@ -110,21 +110,21 @@ char *fake = N_("Direct sum of matrices");
 char *fake = N_("Direct sum of a vector of matrices");
 char *fake = N_("Get the eigenvalues of a matrix (Currently only for up to 4x4 or triangular matrices)");
 char *fake = N_("Get the eigenvalues and eigenvectors of a matrix (Currently only for up to 2x2 matrices)");
-char *fake = N_("Apply the Gram-Schmidt process (to the columns) with respect to inner product given by B (if not given use hermitian product)");
+char *fake = N_("Apply the Gram-Schmidt process (to the columns) with respect to inner product given by B (if not given use Hermitian product)");
 char *fake = N_("Hankel matrix");
 char *fake = N_("Hilbert matrix of order n");
 char *fake = N_("Get the image (columnspace) of a linear transform");
 char *fake = N_("Get the Inf Norm of a vector");
 char *fake = N_("Get the invariant factors of a square integer matrix (not its characteristic)");
 char *fake = N_("Inverse Hilbert matrix of order n");
-char *fake = N_("Is a matrix hermitian");
+char *fake = N_("Is a matrix Hermitian");
 char *fake = N_("Test if a vector is in a subspace");
 char *fake = N_("Is a matrix (or number) invertible (Integer matrix is invertible iff it's invertible over the integers)");
 char *fake = N_("Is a matrix (or number) invertible over a field");
 char *fake = N_("Is a matrix normal");
 char *fake = N_("Is a matrix positive definite");
 char *fake = N_("Is a matrix positive semidefinite");
-char *fake = N_("Is a matrix skew-hermitian");
+char *fake = N_("Is a matrix skew-Hermitian");
 char *fake = N_("Is a matrix unitary");
 char *fake = N_("Get the jordan block corresponding to lambda and n");
 char *fake = N_("Get the kernel (nullspace) of a linear transform");
@@ -134,7 +134,7 @@ char *fake = N_("Return the columns that are not the pivot columns of a matrix")
 char *fake = N_("Get the p Norm (or 2 Norm if no p is supplied) of a vector");
 char *fake = N_("Get the nullity of a matrix");
 char *fake = N_("Get the orthogonal complement of the columnspace");
-char *fake = N_("Projection of vector v onto subspace W given a sesquilinear form B (if not given use hermitian product)");
+char *fake = N_("Projection of vector v onto subspace W given a sesquilinear form B (if not given use Hermitian product)");
 char *fake = N_("Get the QR decomposition of A, returns R and Q can be a reference");
 char *fake = N_("Get the rank of a matrix");
 char *fake = N_("Return the Rayleigh quotient of a matrix and a vector");
@@ -229,6 +229,7 @@ char *fake = N_("Convert degrees to radians");
 char *fake = N_("Convert radians to degrees");
 char *fake = N_("Find roots of a cubic polynomial (given as vector of coefficients)");
 char *fake = N_("Use classical Euler's method to numerically solve y'=f(x,y) for initial x0,y0 going to x1 with n increments, returns y at x1");
+char *fake = N_("Use classical Euler's method to numerically solve y'=f(x,y) for initial x0,y0 going to x1 with n increments, returns an n+1 by 2 matrix of values");
 char *fake = N_("Find root of a function using the bisection method");
 char *fake = N_("Find root of a function using the method of false position");
 char *fake = N_("Find root of a function using the Muller's method");
@@ -236,6 +237,7 @@ char *fake = N_("Find root of a function using the secant method");
 char *fake = N_("Find roots of a polynomial (given as vector of coefficients)");
 char *fake = N_("Find roots of a quartic polynomial (given as vector of coefficients)");
 char *fake = N_("Use classical non-adaptive Runge-Kutta of fourth order method to numerically solve y'=f(x,y) for initial x0,y0 going to x1 with n increments, returns y at x1");
+char *fake = N_("Use classical non-adaptive Runge-Kutta of fourth order method to numerically solve y'=f(x,y) for initial x0,y0 going to x1 with n increments, returns an n+1 by 2 matrix of values");
 char *fake = N_("Calculate average of an entire matrix");
 char *fake = N_("Integral of the GaussFunction from 0 to x (area under the normal curve)");
 char *fake = N_("The normalized Gauss distribution function (the normal curve)");
